@@ -9,17 +9,20 @@ use warnings;
 use strict;
 
 use utf8;
-#use POSIX qw/setlocale/;
-#setlocale(&POSIX::LC_ALL, "en_US");
+use POSIX qw/setlocale/;
 use locale;
 
+BEGIN {
+    setlocale(&POSIX::LC_CTYPE, "pt_PT");
+}
+
 use Time::HiRes;
 use Lingua::PTD::Dumper;
 use Lingua::PTD::BzDmp;
 use Lingua::PTD::XzDmp;
 use Lingua::PTD::SQLite;
 
-our $VERSION = '1.04_03';
+our $VERSION = '1.04_04';
 
 =encoding UTF-8
 
@@ -706,10 +709,6 @@ sensitive alignment.
 sub lowercase {
     my ($self, %ops) = @_;
 
-    print STDERR "\n\n";
-    print STDERR "--> ", join(" ", ord("ç"), ord(lc "Ç"), ord("ã"), ord(lc "Ã"));
-    print STDERR "\n\n";
-
     $ops{verbose} //= $self->verbose;
 
     $self->downtr(
